==> h-orm-0.0.1-sources.jar: cn/sylinx/horm/core/TransactionSupportOrmClient.java <==
package cn.sylinx.horm.core;

import java.sql.SQLException;
import cn.sylinx.horm.core.datasource.ConnectionProvider;
import cn.sylinx.horm.core.datasource.TransactionalConnectionProvider;
import cn.sylinx.horm.exception.ErrorCodeRecordable;
import cn.sylinx.horm.exception.TransactionException;
import cn.sylinx.horm.transaction.jdbc.ITransactionBlock;
import cn.sylinx.horm.transaction.jdbc.TransactionSupport;
import cn.sylinx.horm.util.GLog;
import cn.sylinx.horm.util.Ret;

/**
 * jdbc 事务
 * 
 * @author johnhan
 *
 */
public class TransactionSupportOrmClient extends OrmClient implements TransactionSupport {
	@Override
	public Ret transaction(ITransactionBlock transaction) throws SQLException {
		ConnectionProvider connectionProvider = getConnectionProvider();
		if (connectionProvider == null || !(connectionProvider instanceof TransactionalConnectionProvider)) {
			throw new TransactionException("不支持事务处理");
		}
		TransactionalConnectionProvider transactionalConnectionProvider = (TransactionalConnectionProvider) connectionProvider;
		// 开始事务
		transactionalConnectionProvider.startTransaction(transaction.transactionIsolation());
		try {
			Ret ret = transaction.run();
			if (ret.isSuccess()) {
				// 提交事务
				transactionalConnectionProvider.commitTransaction();
			} else {
				// 回滚事务
				transactionalConnectionProvider.rollbackTransaction();
			}
			return ret;
		} catch (Throwable t) {
			GLog.error("事务处理异常", t);
			transactionalConnectionProvider.rollbackTransaction();
			int code = 500;
			if (ErrorCodeRecordable.class.isAssignableFrom(t.getClass())) {
				code = ((ErrorCodeRecordable) t).getCode();
			}
			return Ret.error(code, t.getMessage(), t);
		}
	}
}

==> h-orm-0.1.5-sources.jar: cn/sylinx/horm/core/TransactionSupportOrmClient.java <==
package cn.sylinx.horm.core;

import cn.sylinx.horm.core.datasource.ConnectionProvider;
import cn.sylinx.horm.core.datasource.TransactionalConnectionProvider;
import cn.sylinx.horm.exception.ErrorCodeRecordable;
import cn.sylinx.horm.exception.TransactionException;
import cn.sylinx.horm.transaction.jdbc.ITransactionBlock;
import cn.sylinx.horm.transaction.jdbc.TransactionSupport;
import cn.sylinx.horm.util.GLog;
import cn.sylinx.horm.util.Ret;

/**
 * jdbc 事务
 * 
 * @author johnhan
 *
 */
public class TransactionSupportOrmClient extends OrmClient implements TransactionSupport {
	@Override
	public Ret transaction(ITransactionBlock transaction) {
		ConnectionProvider connectionProvider = getConnectionProvider();
		if (connectionProvider == null || !(connectionProvider instanceof TransactionalConnectionProvider)) {
			throw new TransactionException("不支持事务处理");
		}
		TransactionalConnectionProvider transactionalConnectionProvider = (TransactionalConnectionProvider) connectionProvider;
		// 开始事务
		transactionalConnectionProvider.startTransaction(transaction.transactionIsolation());
		try {
			Ret ret = transaction.run();
			if (ret.isSuccess()) {
				// 提交事务
				transactionalConnectionProvider.commitTransaction();
			} else {
				// 回滚事务
				transactionalConnectionProvider.rollbackTransaction();
			}
			return ret;
		} catch (Throwable t) {
			GLog.error("事务处理异常", t);
			transactionalConnectionProvider.rollbackTransaction();
			int code = 500;
			if (ErrorCodeRecordable.class.isAssignableFrom(t.getClass())) {
				code = ((ErrorCodeRecordable) t).getCode();
			}
			return Ret.error(code, t.getMessage(), t);
		}
	}

	@Override
	public String toString() {
		return "TransactionSupportOrmClient [DbType --> " + getDialect().getDbType().getValue() + ", DataSourceName --> "
				+ getDataSourceName() + "]";
	}

}
